@@ -22,7 +22,7 @@
  * @file AbstractCommandExecutor.php
  * @brief svn add
  * @author <a href="kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: AbstractCommandExecutor.php 15 2007-07-18 15:02:48Z ishitoya $
+ * @version $Id: AbstractCommandExecutor.php 19 2007-07-25 18:20:09Z ishitoya $
  *
  * executes phing abstract class
  */
@@ -98,9 +98,11 @@ extends Ficus_Bean implements Ficus_CommandExecutor
      */
     protected function addOption($command, $option, $value = null){
         if(is_null($value)){
-            $command .= " $option";
+            $option = preg_replace('/[\/\\\]+/', "/", $option);
+            $command .= " " . $option;
         }else{
-            $command .= " $option $value";
+            $value = preg_replace('/[\/\\\]+/', "/", $value);
+            $command .= " " . $option . " " . $value;
         }
         return $command;
     }
