@@ -22,7 +22,7 @@
  * @file S2DaoManager.php
  * @brief s2dao manager
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: S2DaoManager.php 14 2007-07-18 14:55:12Z ishitoya $
+ * @version $Id: S2DaoManager.php 19 2007-07-25 18:20:09Z ishitoya $
  */
 
 require_once("ficus/config/Registry.php");
@@ -50,7 +50,11 @@ class Ficus_S2DaoManager{
      * @param $id id
      */
     public function getSingleEntity($id){
-        $entity = $this->dao->getById($id);
+        if($id instanceof Ficus_S2DaoDataTransferObject){
+            $entity = $this->dao->getWithCondition($id);
+        }else{
+            $entity = $this->dao->getById($id);
+        }
         if($entity->isEmpty()){
             return null;
         }
@@ -104,6 +108,13 @@ class Ficus_S2DaoManager{
         return $this->dao;
     }
 
+    /**
+     * get dto
+     */
+    public function dto(){
+        return $this->dao->dto();
+    }
+
     /**
      * entity
      */
