@@ -22,7 +22,7 @@
  * @file Pages.php
  * @brief abstract page
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: Page.php 17 2007-07-19 13:33:15Z ishitoya $
+ * @version $Id: Page.php 19 2007-07-25 18:20:09Z ishitoya $
  */
 
 require_once("ficus/pages/PageConstants.php");
@@ -88,6 +88,7 @@ abstract class Ficus_Page extends Ficus_Bean implements Ficus_PageConstants{
         if($this->methodExists($method) == false){
             return parent::__call($name, $args);
         }
+        
         $this->currentAction = $name;
         try{
             $this->assign(self::CURRENT_PAGENAME, $this->pagename);
@@ -197,10 +198,23 @@ abstract class Ficus_Page extends Ficus_Bean implements Ficus_PageConstants{
      * @param $actionname string actionname
      */
     protected function forward($pagename, $actionname = null, $buffering = false){
+        if($pagename == $this->pagename()){
+            return $this->pass($actionname);
+        }
         $controller = Ficus_PageComponentFactory::getPageController();
         return $controller->execute($pagename, $actioname, $buffering);
     }
 
+    /**
+     * pass action in the page
+     * @param $action name string actionname
+     */
+    protected function pass($actionname, $args = null){
+        if(is_null($args)){
+            return $this->{$actionname}($this->request);
+        }
+    }
+
     /**
      * move
      * @param $pagename string target pagename
