@@ -22,7 +22,7 @@
  * @file PageController.php
  * @brief controll page
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: PageController.php 7 2007-07-14 10:55:18Z ishitoya $
+ * @version $Id: PageController.php 19 2007-07-25 18:20:09Z ishitoya $
  */
 
 require_once("smarty/Smarty.class.php");
@@ -55,7 +55,11 @@ class Ficus_PageController implements Ficus_PageConstants{
      * mode extractor
      */
     protected $extractor = null;
-
+    /**
+     * @var $chain Ficus_PageActionSet
+     */
+    protected $chain = null;
+    
     /**
      * constructor
      */
@@ -64,6 +68,7 @@ class Ficus_PageController implements Ficus_PageConstants{
             Ficus_Dir::normalize(Ficus_File::currentDir() . "/templates");
         Ficus_PageComponentFactory::getSmarty()->addPath(self::TEMPLATE_NAME,
                                                          $templates);
+        $this->chain = new Ficus_PageActionSet();
     }
 
     /**
@@ -116,6 +121,8 @@ class Ficus_PageController implements Ficus_PageConstants{
                 $page->disableOutputBuffering();
             }
         }
+        
+        $this->chain->add($name, $mode);
         return call_user_func(array($page, $mode), $request);
     }
 
@@ -149,5 +156,12 @@ class Ficus_PageController implements Ficus_PageConstants{
     protected function isPageExists($name){
         return array_key_exists($name, $this->pages);
     }
+
+    /**
+     * chain
+     */
+    public function chain(){
+        return $this->chain;
+    }
 }
 ?>
\ No newline at end of file
