@@ -22,7 +22,7 @@
  * @file EditScaffoldForeperson.php
  * @brief table manager page
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: EditScaffoldForeperson.php 14 2007-07-18 14:55:12Z ishitoya $
+ * @version $Id: EditScaffoldForeperson.php 19 2007-07-25 18:20:09Z ishitoya $
  */
 
 require_once("ficus/pages/AbstractPage.php");
@@ -32,14 +32,34 @@ require_once("ficus/config/Registry.php");
  * @class Ficus_EditScaffoldForeperson
  */
 class Ficus_EditScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
+    protected $entity = null;
+
+    /**
+     * get entity
+     */
+    public function entity(){
+        return $this->entity;
+    }
+    
+    /**
+     * prepare
+     */
+    protected function prepare($action){
+        if($action === self::DO_DEFAULT){
+            $id = $this->mediator->request()->extractAsInt(self::KEY_ID);
+            $this->entity =
+                $this->mediator->daoManager()->getSingleEntity($id);
+        }else{
+            $this->entity = $this->mediator->getEntityFromRequest();
+        }            
+    }
+    
     /**
      * edit
      * @param $args array of arguments
      */ 
     public function doDefault(){
-        $id = $this->mediator->request()->extractAsInt(self::KEY_ID);
-        $entity = $this->mediator->daoManager()->getSingleEntity($id);
-        return $this->buildEdit($entity);
+        return $this->buildEdit($this->entity);
     }
 
     /**
@@ -47,8 +67,7 @@ class Ficus_EditScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
      * @param $args array of arguments
      */
     public function doChildren(){
-        $entity = $this->mediator->getEntityFromRequest();
-        return $this->buildNew($entity);
+        return $this->buildEdit($this->entity);
     }
 
     /**
@@ -56,8 +75,7 @@ class Ficus_EditScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
      * @param $args array of arguments
      */
     public function doConfirm(){
-        $entity = $this->mediator->getEntityFromRequest();
-        $container = $this->mediator->getContainer($entity);
+        $container = $this->mediator->getContainer($this->entity);
         
         $organizer =
             $this->mediator->organizerFactory()->createViewOrganizer();
@@ -68,6 +86,7 @@ class Ficus_EditScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
         $container->addOrganizers(
             $this->mediator->organizerFactory()->createHiddenOrganizer());
         $this->mediator->formBean()->setDo(self::DO_SUBMIT);
+        $this->mediator->setEntity($this->entity);
         return $container->build();
     }
 
@@ -76,8 +95,7 @@ class Ficus_EditScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
      * @param $args array of arguments
      */
     public function doSubmit(){
-        $entity = $this->mediator->getEntityFromRequest();
-        $container = $this->mediator->getContainer($entity);
+        $container = $this->mediator->getContainer($this->entity);
         
         $organizer =
             $this->mediator->organizerFactory()->createViewOrganizer();
@@ -87,8 +105,9 @@ class Ficus_EditScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
 
         $container->addOrganizers($organizer);
 
-        $entity->update();
+        $this->entity->update();
 
+        $this->mediator->setEntity($this->entity);
         return $container->build();
     }
 
@@ -118,6 +137,7 @@ class Ficus_EditScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
             $this->mediator->formBean()->setDo(self::DO_CHILDREN);
             $this->mediator->formBean()->setTransition($transition);
         }
+        $this->mediator->setEntity($entity);
         return $container->build();
     }
 }    
