@@ -22,7 +22,7 @@
  * @file ScaffoldConfiguration.php
  * @brief ScaffoldConfiguration.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: ScaffoldConfiguration.php 17 2007-07-19 13:33:15Z ishitoya $
+ * @version $Id: ScaffoldConfiguration.php 19 2007-07-25 18:20:09Z ishitoya $
  *
  */
 
@@ -74,6 +74,10 @@ class Ficus_ScaffoldConfiguration implements Ficus_ScaffoldConstants{
         $config = new Ficus_ScaffoldTableConfiguration();
         if(isset($settings[self::REGISTRY_EXCLUDES])){
             foreach($settings[self::REGISTRY_EXCLUDES] as $context => $qnames){
+                if(is_array($qnames) === false){
+                    $config->addExcludeProperty($context, "");
+                    continue;
+                }
                 foreach($qnames as $qname){
                     $config->addExcludeProperty($context, $qname);
                 }
@@ -99,7 +103,9 @@ class Ficus_ScaffoldConfiguration implements Ficus_ScaffoldConstants{
             $config->setProperties($settings[self::REGISTRY_PROPERTIES]);
         }
         if(isset($settings[self::REGISTRY_NOCHILDREN])){
-            $config->setNoChildren(true);
+            foreach($settings[self::REGISTRY_NOCHILDREN] as $context => $nochildren){
+                $config->addNoChildren($context, $nochildren);
+            }
         }
         return $config;
     }
