@@ -22,7 +22,7 @@
  * @file Form bean.php
  * @brief Form bean.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: ScaffoldFormBean.php 15 2007-07-18 15:02:48Z ishitoya $
+ * @version $Id: ScaffoldFormBean.php 19 2007-07-25 18:20:09Z ishitoya $
  *
  */
 
@@ -34,6 +34,7 @@ require_once("ficus/db/s2dao/models/S2DaoDataAccessObject.php");
  */
 class Ficus_ScaffoldFormBean extends Ficus_Bean
 implements Ficus_ScaffoldConstants{
+    const DEFAULT_SUBMITTITLE = "次へ";
     /**
      * $page string form action
      */
@@ -62,7 +63,7 @@ implements Ficus_ScaffoldConstants{
     /**
      * $submitTitle string submit button value
      */
-    protected $submitTitle = self::SUBMIT_TITLE;
+    protected $submitTitle = self::DEFAULT_SUBMITTITLE;
 
     /**
      * $transition string transition
