@@ -22,7 +22,7 @@
  * @file ScaffoldManager.php
  * @brief index page of administrator site
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: ScaffoldManager.php 15 2007-07-18 15:02:48Z ishitoya $
+ * @version $Id: ScaffoldManager.php 19 2007-07-25 18:20:09Z ishitoya $
  */
 
 require_once("ficus/config/Registry.php");
@@ -174,6 +174,13 @@ implements Ficus_ScaffoldConstants{
         return $this->mediator;
     }
 
+    /**
+     * get foreperson
+     */
+    public function foreperson(){
+        return $this->foreperson;
+    }
+
     /**
      * organize a scaffold
      */
@@ -260,17 +267,23 @@ implements Ficus_ScaffoldConstants{
      * @return UTil_ScaffoldForeperson
      */
     protected function createForeperson($action){
+        if($this->mediator->request()->has(self::KEY_DO)){
+            $do = $this->mediator->request()->extractAsString(self::KEY_DO);
+        }else{
+            $do = self::DO_DEFAULT;
+        }
+
         switch($action){
         case(self::ACTION_VIEW):
-            return new Ficus_ViewScaffoldForeperson($this->mediator); 
+            return new Ficus_ViewScaffoldForeperson($this->mediator, $do); 
         case(self::ACTION_LIST):
-            return new Ficus_ListScaffoldForeperson($this->mediator);
+            return new Ficus_ListScaffoldForeperson($this->mediator, $do);
         case(self::ACTION_EDIT):
-            return new Ficus_EditScaffoldForeperson($this->mediator);
+            return new Ficus_EditScaffoldForeperson($this->mediator, $do);
         case(self::ACTION_NEW):
-            return new Ficus_NewScaffoldForeperson($this->mediator);
+            return new Ficus_NewScaffoldForeperson($this->mediator, $do);
         case(self::ACTION_DELETE):
-            return new Ficus_DeleteScaffoldForeperson($this->mediator);
+            return new Ficus_DeleteScaffoldForeperson($this->mediator, $do);
         default: throw new Ficus_NotSupportedException("scaffold foreperson $action is not available");
         }
     }
