@@ -22,7 +22,7 @@
  * @file ScaffoldPages.php
  * @brief abstract buffered page
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: ScaffoldPage.php 15 2007-07-18 15:02:48Z ishitoya $
+ * @version $Id: ScaffoldPage.php 19 2007-07-25 18:20:09Z ishitoya $
  */
 
 require_once("ficus/pages/BufferedPage.php");
@@ -35,6 +35,8 @@ implements Ficus_ScaffoldConstants{
     protected $manager = null;
     protected $target = null;
     protected $foreperson = null;
+    protected $scaffold = null;
+    protected $currentScaffoldAction = null;
 
     /**
      * on called
@@ -43,6 +45,7 @@ implements Ficus_ScaffoldConstants{
      */
     protected function onDo($mode, $args){
         if(($action = $this->isScaffoldAction($mode))){
+            $this->scaffold = null;
             Ficus_PageComponentFactory::getSmarty()->addPath(self::SMARTY_SCAFFOLD, Ficus_Dir::normalize(Ficus_File::currentDir() . "/templates"));
             if(empty($this->target)){
                 if($this->request->has(self::KEY_TARGET)){
@@ -56,6 +59,7 @@ implements Ficus_ScaffoldConstants{
             $action = $this->getScaffoldAction($action);
             $this->setNextAction($action);
             $this->manager = new Ficus_ScaffoldManager($this);
+            $this->currentScaffoldAction = $this->manager->formBean()->do();
         }
     }
 
@@ -63,8 +67,8 @@ implements Ficus_ScaffoldConstants{
      * exec scaffold
      */
     protected function buildScaffold(){
-        $scaffold = $this->manager->organize();
-        $this->assign(self::SMARTY_SCAFFOLD, $scaffold);
+        $this->scaffold = $this->manager->organize();
+        $this->assign(self::SMARTY_SCAFFOLD, $this->scaffold);
     }
 
     /**
@@ -80,9 +84,15 @@ implements Ficus_ScaffoldConstants{
 
             $mode = $this->foreperson;
             $template = $this->getModeTemplate($mode);
+
+            $result = $this->dispatchScaffoldEvent("done", $args);
+            if(is_null($result)){
+                $result = $template;
+            }
+
             if(Ficus_PageComponentFactory::getSmarty()
-               ->isTemplateExists($template)){
-                return parent::onDone($mode, $args, $template);
+               ->isTemplateExists($result)){
+                return parent::onDone($mode, $args, $result);
             }else{
                 return parent::onDone($mode, $args,
                                       self::DEFAULT_SCAFFOLD_TEMPLATE);
@@ -94,11 +104,12 @@ implements Ficus_ScaffoldConstants{
     /**
      * scaffold
      */
-    protected function execScaffoldAction($arg){
-        $result = $this->dispatchScaffoldEvent($args);
+    protected function execScaffoldAction($args){
+        $result = $this->dispatchScaffoldEvent("do", $args);
         if(is_null($result)){
             return self::MODE_TEMPLATE;
         }
+        return $result;
     }
 
     /**
@@ -160,16 +171,32 @@ implements Ficus_ScaffoldConstants{
     /**
      * call event handler
      */
-    protected function dispatchScaffoldEvent($args){
-        $do = $this->manager->formBean()->do();
-        $methodDefault = "onDoScaffold" . ucfirst($this->foreperson);
-        $method = $methodDefault . ucfirst($do);
+    protected function dispatchScaffoldEvent($context, $args){
+        $prefix = "on" . ucfirst($context) . "Scaffold";
+        $methodDefault = $prefix. ucfirst($this->foreperson);
+        $method = $methodDefault . ucfirst($this->currentScaffoldAction);
+        if(method_exists($this, $method)){
+            return $this->{$method}($args);
+        }
+
+        $pair =
+            Ficus_PageComponentFactory::getPageController()->chain()->prev();
+        if(is_null($pair) == false){
+            $action = $pair->action();
+            $method = "on" . ucfirst($context) . ucfirst($action) . "Scaffold" . ucfirst($this->foreperson) . ucfirst($this->currentScaffoldAction);
+            if(method_exists($this, $method)){
+                return $this->{$method}($args);
+            }
+        }
+
+        $method = "on" . ucfirst($context) . ucfirst($this->target) . "Scaffold" . ucfirst($this->foreperson) . ucfirst($this->currentScaffoldAction);
         if(method_exists($this, $method)){
             return $this->{$method}($args);
         }
         if(method_exists($this, $methodDefault)){
             return $this->{$methodDefault}($args);
         }
+        
         return null;
     }
 }
