@@ -22,7 +22,7 @@
  * @file ScaffoldTableConfiguration.php
  * @brief ScaffoldTableConfiguration.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: ScaffoldTableConfiguration.php 17 2007-07-19 13:33:15Z ishitoya $
+ * @version $Id: ScaffoldTableConfiguration.php 19 2007-07-25 18:20:09Z ishitoya $
  *
  */
 
@@ -51,7 +51,7 @@ implements Ficus_ScaffoldConstants, Ficus_S2DaoModelConstants{
     /**
      * no children
      */
-    protected $noChildren = true;
+    protected $noChildren = array("*" => true);
 
     /**
      * transitions
@@ -86,13 +86,47 @@ implements Ficus_ScaffoldConstants, Ficus_S2DaoModelConstants{
         $qname = $this->getQname($part);
         $qname .= "." . $part->name();
 
+        $page = Ficus_PageComponentFactory::getPageController()->chain()
+                                                          ->current()->page();
+
+        if(isset($this->excludes[$page . "." . self::TOKEN_ALL]) ||
+           isset($this->excludes[$page . "." . $context]) ||
+           isset($this->patternExcludes[$page . "." . self::TOKEN_ALL]) ||
+           isset($this->patternExcludes[$page . "," . $context])){
+            if(isset($this->excludes[$page . "." . self::TOKEN_ALL][$qname]) ||
+               isset($this->excludes[$page . "." . $context][$qname])){
+                return true;
+            }
+            if(isset($this->patternExcludes[$page . "." . self::TOKEN_ALL])){
+                foreach($this->patternExcludes[$page . "." . self::TOKEN_ALL]
+                        as $pattern){
+                    if(preg_match('/' . $pattern . '/', $qname)){
+                        return true;
+                    }
+                }
+            }
+            if(isset($this->patternExcludes[$page . "." . $context])){
+                foreach($this->patternExcludes[$page . "." . $context]
+                        as $pattern){
+                    if(preg_match('/' . $pattern . '/', $qname)){
+                        return true;
+                    }
+                }
+            }
+            return false;
+        }            
+        
         if((isset($this->excludes[self::TOKEN_ALL]) &&
-            isset($this->excludes[self::TOKEN_ALL][$qname])) ||
-           (isset($this->excludes[$context]) &&
-            isset($this->excludes[$context][$qname]))){
+            isset($this->excludes[self::TOKEN_ALL][$qname]))){
             return true;
         }
 
+        if(isset($this->excludes[$context]) &&
+           isset($this->excludes[$context][$qname])){
+            return true;
+        }
+
+
         if(isset($this->patternExcludes[self::TOKEN_ALL])){
             foreach($this->patternExcludes[self::TOKEN_ALL] as $pattern){
                 if(preg_match('/' . $pattern . '/', $qname)){
@@ -182,8 +216,19 @@ implements Ficus_ScaffoldConstants, Ficus_S2DaoModelConstants{
     /**
      * is no children
      */
-    public function isNoChildren(){
-        return $this->noChildren;
+    public function isNoChildren($context){
+        $page = Ficus_PageComponentFactory::getPageController()->chain()
+                                                          ->current()->page();
+        if(isset($this->noChildren[$page])){
+            return $this->noChildren[$page];
+        }
+        if(isset($this->noChildren[$context])){
+            return $this->noChildren[$context];
+        }
+        if(isset($this->noChildren[self::TOKEN_ALL])){
+            return $this->noChildren[self::TOKEN_ALL];
+        }
+        return false;
     }
 
     /**
@@ -214,8 +259,12 @@ implements Ficus_ScaffoldConstants, Ficus_S2DaoModelConstants{
      * set no children
      * @param $noChildren boolean set to true, ignore child entities
      */
-    public function setNoChildren($noChildren){
-        $this->noChildren = $noChildren;
+    public function addNoChildren($context, $noChildren){
+        $contexts = explode(",", $context);
+        foreach($contexts as $context){
+            $context = trim($context);
+            $this->noChildren[$context] = $noChildren;
+        }
     }
 
     /**
