@@ -22,7 +22,7 @@
  * @file EditScaffoldOrganizer.php
  * @brief EditScaffoldOrganizer.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: EditScaffoldOrganizer.php 17 2007-07-19 13:33:15Z ishitoya $
+ * @version $Id: EditScaffoldOrganizer.php 19 2007-07-25 18:20:09Z ishitoya $
  *
  */
 
@@ -55,7 +55,7 @@ extends Ficus_AbstractScaffoldOrganizer{
     protected function onVisit($part){
         $config = $this->mediator->table();
         if($part->type() == self::TYPE_DIRECT ||
-           ($config->isExcludeProperty($part, self::ACTION_NEW) &&
+           ($config->isExcludeProperty($part, self::ACTION_EDIT) &&
            $config->isTransitionParentProperty($part) == false)){
             $this->hiddens[] = $part;
             return;
@@ -69,7 +69,7 @@ extends Ficus_AbstractScaffoldOrganizer{
                 $this->assign("items", $part->value()->names());
                 $this->assign("selected", $part->value()->id());
                 $input = $this->fetch("select");
-            }else if($config->isNoChildren()){
+            }else if($config->isNoChildren(self::ACTION_EDIT)){
                 return;
             }else{
                 $input = $this->getChildren($part);
