@@ -22,7 +22,7 @@
  * @file ListScaffoldOrganizer.php
  * @brief ListScaffoldOrganizer.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: ListScaffoldOrganizer.php 17 2007-07-19 13:33:15Z ishitoya $
+ * @version $Id: ListScaffoldOrganizer.php 19 2007-07-25 18:20:09Z ishitoya $
  *
  */
 
@@ -98,9 +98,7 @@ extends Ficus_AbstractScaffoldOrganizer{
             }
             $container = $container->get(0);
             $parts = $container->parts();
-            $this->assign("delete", "delete");
             $this->header = $this->createHeader($parts);
-            $this->clear("delete");
         }
     }
 
