@@ -22,7 +22,7 @@
  * @file NewScaffoldOrganizer.php
  * @brief NewScaffoldOrganizer.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: NewScaffoldOrganizer.php 17 2007-07-19 13:33:15Z ishitoya $
+ * @version $Id: NewScaffoldOrganizer.php 19 2007-07-25 18:20:09Z ishitoya $
  *
  */
 
@@ -76,7 +76,7 @@ extends Ficus_AbstractScaffoldOrganizer{
                 $this->assign("items", $part->value()->names());
                 $this->assign("selected", $key);
                 $input = $this->fetch("select");
-            }else if($config->isNoChildren()){
+            }else if($config->isNoChildren(self::ACTION_NEW)){
                 return;
             }else{
                 $input = $this->getChildren($part);
