@@ -22,7 +22,7 @@
  * @file ScaffoldMediator.php
  * @brief ScaffoldMediator.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: ScaffoldMediator.php 14 2007-07-18 14:55:12Z ishitoya $
+ * @version $Id: ScaffoldMediator.php 19 2007-07-25 18:20:09Z ishitoya $
  *
  */
 
@@ -72,6 +72,11 @@ class Ficus_ScaffoldMediator implements Ficus_ScaffoldConstants{
      */
     protected $form = null;
 
+    /**
+     * dto
+     */
+    protected $condition = null;
+
     /**
      * construct
      * @param $target string target entity name
@@ -122,6 +127,13 @@ class Ficus_ScaffoldMediator implements Ficus_ScaffoldConstants{
         $this->form = $bean;
     }
 
+    /**
+     * set condition
+     */
+    public function setCondition($condition){
+        $this->condition = $condition;
+    }
+
     /**
      * get form bean
      */
@@ -149,6 +161,16 @@ class Ficus_ScaffoldMediator implements Ficus_ScaffoldConstants{
     public function entity(){
         return $this->entity;
     }
+
+    /**
+     * get condition
+     */
+    public function condition(){
+        if(is_null($this->condition)){
+            return $this->daoManager()->getPagerDto();
+        }
+        return $this->condition;
+    }
     
     /**
      * get smarty
